﻿using Hotline.Ai.Visit;
using Hotline.Caching.Interfaces;
using Hotline.Orders;
using StackExchange.Redis;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using XF.Domain.Constants;
using XF.Domain.Dependency;
using XF.Domain.Repository;

namespace Hotline.Application.Visit
{
    public class OrderVisitApplication : IOrderVisitApplication, IScopeDependency
    {
        private readonly IRepository<AiOrderVisit> _aiOrderVisitRepository;
        private readonly IAiVisitService _aiVisitService;
        private readonly ISystemSettingCacheManager _systemSettingCacheManager;

        public OrderVisitApplication(IRepository<AiOrderVisit> aiOrderVisitRepository,IAiVisitService aiVisitService, ISystemSettingCacheManager systemSettingCacheManager)
        {
            _aiOrderVisitRepository = aiOrderVisitRepository;
            _aiVisitService = aiVisitService;
            _systemSettingCacheManager = systemSettingCacheManager;
        }


        public async Task AddAiVisit(string aivisitId, CancellationToken cancellationToken)
        {
            var aiOrderVisit =await _aiOrderVisitRepository.Queryable()
                .Includes(x => x.AiOrderVisitDetails, s => s.Order)
                .Includes(x => x.AiOrderVisitDetails, s => s.OrderVisit)
                .FirstAsync(x => x.Id == aivisitId);

            #region 获取系统设置
            var sceneuid = _systemSettingCacheManager.GetSetting(SettingConstants.VisitSceneUid)?.SettingValue[0];
            var ruleuId = _systemSettingCacheManager.GetSetting(SettingConstants.VisitRuleUid)?.SettingValue[0];
            var visitFromNameKey = _systemSettingCacheManager.GetSetting(SettingConstants.VisitFromNameKey)?.SettingValue[0];
            var visitFromGenderKey = _systemSettingCacheManager.GetSetting(SettingConstants.VisitFromGenderKey)?.SettingValue[0];
            var visitCreationTimeKey = _systemSettingCacheManager.GetSetting(SettingConstants.VisitCreationTimeKey)?.SettingValue[0];
            var visitOrderTitleKey = _systemSettingCacheManager.GetSetting(SettingConstants.VisitOrderTitleKey)?.SettingValue[0];
            var visitIsCallOrderKey = _systemSettingCacheManager.GetSetting(SettingConstants.VisitIsCallOrder)?.SettingValue[0];
            #endregion

            aiOrderVisit = await _aiVisitService.CreateAiOrderVisitTask(aiOrderVisit,sceneuid, ruleuId,visitFromNameKey,visitFromGenderKey,visitCreationTimeKey,visitOrderTitleKey,visitIsCallOrderKey, cancellationToken);

            await _aiOrderVisitRepository.UpdateNav(aiOrderVisit).Include(d => d.AiOrderVisitDetails).ExecuteCommandAsync();
        }
    }
}
